//
// Classe Renderer: desenha os objetos desejados na tela
// e trata eventos de teclado
//
// APENAS os métodos paint e keyboard podem ser alterados.
//
// O método paint desenha a tela: aqui devem ser usados
// os métodos da classe GL (e SOMENTE aqui).
//
// O método keyboard trata eventos de teclado: o sistema de
// janelas envia a posição atual do mouse (que pode ser ignorada,
// se for o caso) e a tecla pressionada no parâmetro "key".
// Ao final, a tela é redesenhada automaticamente.
//
#include <iostream>
#include "Renderer.h"
#include "GL.h"
#include "ListaDeFigurasPolim.h"

using namespace std;

// Construtor recebe a lista, para que seja possível
// desenhar os objetos armazenados
Renderer::Renderer(ListaDeFigurasPolim* lista) {
    this->lista = lista;
}

// Este método deve desenhar os objetos, usando os métodos
// estáticos da classe GL
//
// Ele é chamado toda vez que a aplicação precisa redesenhar
// a tela gráfica. NÃO DEVE SER CHAMADO MANUALMENTE!
void Renderer::paint() {
    //
    // Use os métodos da classe GL para desenhar os objetos da lista
    // Ou melhor, cada objeto deve ser capaz de se auto-desenhar
    // (implemente o método draw() em cada classe derivada de figura)
    //
    // Dica: basta pedir que a lista desenhe todos os objetos...

    cout << "Renderer::paint" << endl;

    // Desenha uma grade
    // Cinza bem claro, para outras cores, veja exemplos em /etc/X11/rgb.txt
    GL::setColor(200,200,200);
    // Ajusta largura da linha (1.0 = 1 pixel de largura)
    GL::setLineWidth(1.0);
    for(int x=-10; x<=10; x+=1) {
        GL::drawLine(x,-10,x,10);
        GL::drawLine(-10,x,10,x);
    }

    // Desenha o sistema de eixos (não alterar)
    // Cinza, para outras cores, veja exemplos em /etc/X11/rgb.txt
    GL::setColor(60,60,60);
    // Linha mais larga
    GL::setLineWidth(3.0);
    GL::drawLine(-10,0,10,0);
    GL::drawLine(0,-10,0,10);

    // Volta ao normal
    //GL::setLineWidth(1.0);

    //
    // Exemplos de uso (retirar após implementar os métodos draw nas classes)
    //
    lista->drawAll();

    // Desenha um retângulo verde centrado em 0,0
    GL::setColor(0,200,0);        // verde claro
    GL::drawRect(-3,-3,3,3);

    // Desenha um círculo vermelho no quadrante superior direito
    GL::setColor(200,0,0);        // vermelho claro
    GL::drawCirc(5,5,3);
}

//
// Trata eventos de teclado: se uma tecla qualquer for pressionada
// durante a execução do programa, este método recebe o seu código
// ASCII na variável key, mais as coordenadas atuais do mouse em x,y
//
// Obs: não trata teclas especiais (F1, setas, etc)
void Renderer::keyboard(unsigned char key, int x, int y) {
    cout << "Renderer::keyboard: " << key << endl;
}

